@@ -32,7 +32,7 @@ sub unlock {
     my ($self) = @_;
     return 0 unless $self->channel->{_is_open}; # This is fugly, the API to AnyEvent::RabbitMQ sucks here..
     my $cv = AnyEvent->condvar;
-    my $t = $self->_gen_timer('Unlock');
+    my $t = $self->_gen_timer($cv, 'Unlock');
     $self->channel->close(
         on_success => sub { $cv->send(1) },
         on_failure => sub { $cv->send(0) },
